"""Constants for Flowrra UI."""

# Task status constants
TASK_STATUSES = ("pending", "running", "success", "failed")

# Status color mapping for CSS classes
STATUS_COLORS = {
    "pending": "yellow",
    "running": "blue",
    "success": "green",
    "failed": "red",
}
