<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}Flowrra{% endblock %}</title>
    <style>
        /* Inline critical CSS - Full stylesheet would be served separately */
        body { margin: 0; font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, sans-serif; }
    </style>
    {% block extra_head %}{% endblock %}
</head>
<body>
    <nav class="navbar">
        <div class="container">
            <div class="nav-brand">
                <a href="/">
                    <h1>⚡ Flowrra</h1>
                </a>
            </div>
            <ul class="nav-menu">
                <li><a href="/" class="{% if request.url.path == '/' %}active{% endif %}">Dashboard</a></li>
                <li><a href="/tasks" class="{% if '/tasks' in request.url.path %}active{% endif %}">Tasks</a></li>
                <li><a href="/schedules" class="{% if '/schedules' in request.url.path %}active{% endif %}">Schedules</a></li>
                <li><a href="/api/health" target="_blank">API</a></li>
            </ul>
        </div>
    </nav>

    <main class="container">
        {% block content %}{% endblock %}
    </main>

    <footer class="footer">
        <div class="container">
            <p>Flowrra - Distributed Task Queue</p>
        </div>
    </footer>

    {% block extra_scripts %}{% endblock %}
</body>
</html>
